[−][src]Enum solana_move_loader_api::account_state::LibraAccountState
Type of Libra account held by a Solana account
Variants
No data for this account yet
CompiledProgram(String)Json string representation of types::transaction::Program
Serialized verified program bytes
Fields of VerifiedProgram
script_bytes: Vec<u8>modules_bytes: Vec<ModuleBytes>Associated genesis account and the write set containing the Libra account data
Genesis(WriteSet)Write sets containing the mint and stdlib modules
Methods
impl LibraAccountState[src]
pub fn create_unallocated() -> Self[src]
pub fn create_program(
sender_address: &AccountAddress,
code: &str,
deps: Vec<&Vec<u8>>
) -> Self[src]
sender_address: &AccountAddress,
code: &str,
deps: Vec<&Vec<u8>>
) -> Self
pub fn create_user(owner: &Pubkey, write_set: WriteSet) -> Self[src]
pub fn create_genesis(mint_balance: u64) -> Result<Self, InstructionError>[src]